#[repr(i32)]pub enum AdvmodeMenu {
Show 47 variants
Default = 0,
Look = 1,
ConversationAddress = 2,
ConversationSelect = 3,
ConversationSpeak = 4,
Inventory = 5,
Drop = 6,
ThrowItem = 7,
Wear = 8,
Remove = 9,
Interact = 10,
Put = 11,
PutContainer = 12,
Eat = 13,
ThrowAim = 14,
Fire = 15,
Get = 16,
Unk17 = 17,
CombatPrefs = 18,
Companions = 19,
MovementPrefs = 20,
SpeedPrefs = 21,
InteractAction = 22,
MoveCarefully = 23,
Announcements = 24,
UseBuilding = 25,
Travel = 26,
Unk27 = 27,
Unk28 = 28,
SleepConfirm = 29,
SelectInteractionTarget = 30,
Unk31 = 31,
Unk32 = 32,
FallAction = 33,
ViewTracks = 34,
Jump = 35,
Unk36 = 36,
AttackConfirm = 37,
AttackType = 38,
AttackBodypart = 39,
AttackStrike = 40,
Unk41 = 41,
Unk42 = 42,
DodgeDirection = 43,
Unk44 = 44,
Unk45 = 45,
Build = 46,
}Variants
Default = 0
Look = 1
ConversationAddress = 2
ConversationSelect = 3
ConversationSpeak = 4
Inventory = 5
Drop = 6
ThrowItem = 7
Wear = 8
Remove = 9
Interact = 10
Put = 11
PutContainer = 12
Eat = 13
ThrowAim = 14
Fire = 15
Get = 16
Unk17 = 17
CombatPrefs = 18
Companions = 19
MovementPrefs = 20
SpeedPrefs = 21
InteractAction = 22
MoveCarefully = 23
Announcements = 24
UseBuilding = 25
Travel = 26
Unk27 = 27
Unk28 = 28
SleepConfirm = 29
SelectInteractionTarget = 30
Unk31 = 31
Unk32 = 32
FallAction = 33
ViewTracks = 34
Jump = 35
Unk36 = 36
AttackConfirm = 37
AttackType = 38
AttackBodypart = 39
AttackStrike = 40
Unk41 = 41
Unk42 = 42
DodgeDirection = 43
Unk44 = 44
Unk45 = 45
Build = 46
Implementations
Sourceimpl AdvmodeMenu
impl AdvmodeMenu
Sourceimpl AdvmodeMenu
impl AdvmodeMenu
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.