pub struct MiscMoveParams {
pub type: Option<i32>,
}Fields
type: Option<i32>Implementations
Sourceimpl MiscMoveParams
impl MiscMoveParams
Sourcepub fn type(&self) -> MiscMoveType
pub fn type(&self) -> MiscMoveType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: MiscMoveType)
pub fn set_type(&mut self, value: MiscMoveType)
Sets type to the provided enum value.