pub struct BasicMaterialInfoMask {
pub states: Vec<i32>,
pub temperature: Option<i32>,
pub flags: Option<bool>,
pub reaction: Option<bool>,
}Fields
states: Vec<i32>temperature: Option<i32>flags: Option<bool>reaction: Option<bool>Implementations
Sourceimpl BasicMaterialInfoMask
impl BasicMaterialInfoMask
Sourcepub fn states(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<StateType>>
pub fn states( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<StateType>>
Returns an iterator which yields the valid enum values contained in states.
Sourcepub fn push_states(&mut self, value: StateType)
pub fn push_states(&mut self, value: StateType)
Appends the provided enum value to states.
Sourcepub fn flags(&self) -> bool
pub fn flags(&self) -> bool
Returns the value of flags, or the default value if flags is unset.
Sourcepub fn reaction(&self) -> bool
pub fn reaction(&self) -> bool
Returns the value of reaction, or the default value if reaction is unset.
Sourcepub fn temperature(&self) -> i32
pub fn temperature(&self) -> i32
Returns the value of temperature, or the default value if temperature is unset.