pub struct GetWorldInfoOut {
pub mode: i32,
pub save_dir: String,
pub world_name: Option<NameInfo>,
pub civ_id: Option<i32>,
pub site_id: Option<i32>,
pub group_id: Option<i32>,
pub race_id: Option<i32>,
pub player_unit_id: Option<i32>,
pub player_histfig_id: Option<i32>,
pub companion_histfig_ids: Vec<i32>,
}Expand description
RPC GetWorldInfo : EmptyMessage -> GetWorldInfoOut
Fields
mode: i32save_dir: Stringworld_name: Option<NameInfo>civ_id: Option<i32>Dwarf mode
site_id: Option<i32>group_id: Option<i32>race_id: Option<i32>player_unit_id: Option<i32>Adventure mode
player_histfig_id: Option<i32>companion_histfig_ids: Vec<i32>Implementations
Sourceimpl GetWorldInfoOut
impl GetWorldInfoOut
Sourcepub fn mode(&self) -> Mode
pub fn mode(&self) -> Mode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn civ_id(&self) -> i32
pub fn civ_id(&self) -> i32
Returns the value of civ_id, or the default value if civ_id is unset.
Sourcepub fn site_id(&self) -> i32
pub fn site_id(&self) -> i32
Returns the value of site_id, or the default value if site_id is unset.
Sourcepub fn group_id(&self) -> i32
pub fn group_id(&self) -> i32
Returns the value of group_id, or the default value if group_id is unset.
Sourcepub fn race_id(&self) -> i32
pub fn race_id(&self) -> i32
Returns the value of race_id, or the default value if race_id is unset.
Sourcepub fn player_unit_id(&self) -> i32
pub fn player_unit_id(&self) -> i32
Returns the value of player_unit_id, or the default value if player_unit_id is unset.
Sourcepub fn player_histfig_id(&self) -> i32
pub fn player_histfig_id(&self) -> i32
Returns the value of player_histfig_id, or the default value if player_histfig_id is unset.