pub struct JobSkillAttr {
pub id: i32,
pub key: String,
pub caption: Option<String>,
pub caption_noun: Option<String>,
pub profession: Option<i32>,
pub labor: Option<i32>,
pub type: Option<String>,
}Fields
id: i32key: Stringcaption: Option<String>caption_noun: Option<String>profession: Option<i32>labor: Option<i32>type: Option<String>Implementations
Sourceimpl JobSkillAttr
impl JobSkillAttr
Sourcepub fn caption(&self) -> &str
pub fn caption(&self) -> &str
Returns the value of caption, or the default value if caption is unset.
Sourcepub fn caption_noun(&self) -> &str
pub fn caption_noun(&self) -> &str
Returns the value of caption_noun, or the default value if caption_noun is unset.
Sourcepub fn profession(&self) -> i32
pub fn profession(&self) -> i32
Returns the value of profession, or the default value if profession is unset.