pub struct ListMaterialsIn {
pub mask: Option<BasicMaterialInfoMask>,
pub id_list: Vec<BasicMaterialId>,
pub builtin: Option<bool>,
pub inorganic: Option<bool>,
pub creatures: Option<bool>,
pub plants: Option<bool>,
}Expand description
RPC ListMaterials : ListMaterialsIn -> ListMaterialsOut
Fields
mask: Option<BasicMaterialInfoMask>id_list: Vec<BasicMaterialId>Specific materials:
builtin: Option<bool>Complete list by type:
inorganic: Option<bool>creatures: Option<bool>plants: Option<bool>Implementations
Sourceimpl ListMaterialsIn
impl ListMaterialsIn
Sourcepub fn builtin(&self) -> bool
pub fn builtin(&self) -> bool
Returns the value of builtin, or the default value if builtin is unset.
Sourcepub fn inorganic(&self) -> bool
pub fn inorganic(&self) -> bool
Returns the value of inorganic, or the default value if inorganic is unset.