pub struct ProfessionAttr {
pub id: i32,
pub key: String,
pub caption: Option<String>,
pub military: Option<bool>,
pub can_assign_labor: Option<bool>,
pub parent: Option<i32>,
}Fields
id: i32key: Stringcaption: Option<String>military: Option<bool>can_assign_labor: Option<bool>parent: Option<i32>Implementations
Sourceimpl ProfessionAttr
impl ProfessionAttr
Sourcepub fn caption(&self) -> &str
pub fn caption(&self) -> &str
Returns the value of caption, or the default value if caption is unset.
Sourcepub fn military(&self) -> bool
pub fn military(&self) -> bool
Returns the value of military, or the default value if military is unset.
Sourcepub fn can_assign_labor(&self) -> bool
pub fn can_assign_labor(&self) -> bool
Returns the value of can_assign_labor, or the default value if can_assign_labor is unset.