pub struct UnitCurseInfo {
pub add_tags1: u32,
pub rem_tags1: u32,
pub add_tags2: u32,
pub rem_tags2: u32,
pub name: Option<NameTriple>,
}Fields
name: Option<NameTriple>Trait Implementations
Sourceimpl Clone for UnitCurseInfo
impl Clone for UnitCurseInfo
Sourcefn clone(&self) -> UnitCurseInfo
fn clone(&self) -> UnitCurseInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnitCurseInfo
impl Debug for UnitCurseInfo
Sourceimpl Default for UnitCurseInfo
impl Default for UnitCurseInfo
Sourceimpl Hash for UnitCurseInfo
impl Hash for UnitCurseInfo
Sourceimpl Message for UnitCurseInfo
impl Message for UnitCurseInfo
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for UnitCurseInfo
impl Name for UnitCurseInfo
Sourceconst NAME: &'static str = "UnitCurseInfo"
const NAME: &'static str = "UnitCurseInfo"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "dfproto"
const PACKAGE: &'static str = "dfproto"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for UnitCurseInfo
impl PartialEq for UnitCurseInfo
Sourceimpl Serialize for UnitCurseInfo
impl Serialize for UnitCurseInfo
impl Eq for UnitCurseInfo
impl StructuralPartialEq for UnitCurseInfo