pub struct SidebarCommand {
pub mode: Option<i32>,
pub menu_index: Option<i32>,
pub action: Option<i32>,
pub selection_coord: Option<Coord>,
}Fields
mode: Option<i32>action: Option<i32>selection_coord: Option<Coord>Implementations
Sourceimpl SidebarCommand
impl SidebarCommand
Sourcepub fn mode(&self) -> UiSidebarMode
pub fn mode(&self) -> UiSidebarMode
Returns the enum value of mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: UiSidebarMode)
pub fn set_mode(&mut self, value: UiSidebarMode)
Sets mode to the provided enum value.
Returns the value of menu_index, or the default value if menu_index is unset.
Sourcepub fn action(&self) -> MenuAction
pub fn action(&self) -> MenuAction
Returns the enum value of action, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: MenuAction)
pub fn set_action(&mut self, value: MenuAction)
Sets action to the provided enum value.