pub struct SidebarState {
pub mode: Option<i32>,
pub menu_items: Vec<MenuItem>,
pub build_selector: Option<BuildSelector>,
}Fields
mode: Option<i32>build_selector: Option<BuildSelector>Implementations
Sourceimpl SidebarState
impl SidebarState
Sourcepub fn mode(&self) -> UiSidebarMode
pub fn mode(&self) -> UiSidebarMode
Returns the enum value of mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: UiSidebarMode)
pub fn set_mode(&mut self, value: UiSidebarMode)
Sets mode to the provided enum value.