#[repr(i32)]pub enum InventoryMode {
Hauled = 0,
Weapon = 1,
Worn = 2,
Piercing = 3,
Flask = 4,
WrappedAround = 5,
StuckIn = 6,
InMouth = 7,
Pet = 8,
SewnInto = 9,
Strapped = 10,
}Variants
Hauled = 0
Weapon = 1
also shield, crutch
Worn = 2
quiver
Piercing = 3
Flask = 4
attached to clothing
WrappedAround = 5
e.g. bandage
StuckIn = 6
InMouth = 7
string descr like Worn
Pet = 8
Left shoulder, right shoulder, or head, selected randomly using pet_seed
SewnInto = 9
Strapped = 10
Implementations
Sourceimpl InventoryMode
impl InventoryMode
Sourceimpl InventoryMode
impl InventoryMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.