#[repr(i32)]pub enum TileDigDesignation {
NoDig = 0,
DefaultDig = 1,
UpDownStairDig = 2,
ChannelDig = 3,
RampDig = 4,
DownStairDig = 5,
UpStairDig = 6,
}Variants
NoDig = 0
no designation
DefaultDig = 1
dig walls, remove stairs and ramps, gather plants, fell trees
UpDownStairDig = 2
ChannelDig = 3
RampDig = 4
DownStairDig = 5
UpStairDig = 6
Implementations
Sourceimpl TileDigDesignation
impl TileDigDesignation
Sourcepub fn from_i32(value: i32) -> Option<TileDigDesignation>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TileDigDesignation>
Use the TryFrom<i32> implementation instead
Converts an i32 to a TileDigDesignation, or None if value is not a valid variant.
Sourceimpl TileDigDesignation
impl TileDigDesignation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.