pub struct ArtImageElement {
pub count: Option<i32>,
pub type: Option<i32>,
pub creature_item: Option<MatPair>,
pub material: Option<MatPair>,
pub id: Option<i32>,
}Fields
count: Option<i32>type: Option<i32>creature_item: Option<MatPair>material: Option<MatPair>id: Option<i32>Implementations
Sourceimpl ArtImageElement
impl ArtImageElement
Sourcepub fn type(&self) -> ArtImageElementType
pub fn type(&self) -> ArtImageElementType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ArtImageElementType)
pub fn set_type(&mut self, value: ArtImageElementType)
Sets type to the provided enum value.