pub struct ArtImageProperty {
pub subject: Option<i32>,
pub object: Option<i32>,
pub verb: Option<i32>,
pub type: Option<i32>,
}Fields
subject: Option<i32>object: Option<i32>verb: Option<i32>type: Option<i32>Implementations
Sourceimpl ArtImageProperty
impl ArtImageProperty
Sourcepub fn subject(&self) -> i32
pub fn subject(&self) -> i32
Returns the value of subject, or the default value if subject is unset.
Sourcepub fn object(&self) -> i32
pub fn object(&self) -> i32
Returns the value of object, or the default value if object is unset.
Sourcepub fn verb(&self) -> ArtImageVerb
pub fn verb(&self) -> ArtImageVerb
Returns the enum value of verb, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_verb(&mut self, value: ArtImageVerb)
pub fn set_verb(&mut self, value: ArtImageVerb)
Sets verb to the provided enum value.
Sourcepub fn type(&self) -> ArtImagePropertyType
pub fn type(&self) -> ArtImagePropertyType
Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ArtImagePropertyType)
pub fn set_type(&mut self, value: ArtImagePropertyType)
Sets type to the provided enum value.