pub struct BodyPartRaw {
pub token: Option<String>,
pub category: Option<String>,
pub parent: Option<i32>,
pub flags: Vec<bool>,
pub layers: Vec<BodyPartLayerRaw>,
pub relsize: Option<i32>,
}Fields
token: Option<String>category: Option<String>parent: Option<i32>flags: Vec<bool>layers: Vec<BodyPartLayerRaw>relsize: Option<i32>Implementations
Sourceimpl BodyPartRaw
impl BodyPartRaw
Sourcepub fn token(&self) -> &str
pub fn token(&self) -> &str
Returns the value of token, or the default value if token is unset.
Sourcepub fn category(&self) -> &str
pub fn category(&self) -> &str
Returns the value of category, or the default value if category is unset.