BuildingInstance

Struct BuildingInstance 

pub struct BuildingInstance {
Show 15 fields pub index: i32, pub pos_x_min: Option<i32>, pub pos_y_min: Option<i32>, pub pos_z_min: Option<i32>, pub pos_x_max: Option<i32>, pub pos_y_max: Option<i32>, pub pos_z_max: Option<i32>, pub building_type: Option<BuildingType>, pub material: Option<MatPair>, pub building_flags: Option<u32>, pub is_room: Option<bool>, pub room: Option<BuildingExtents>, pub direction: Option<i32>, pub items: Vec<BuildingItem>, pub active: Option<i32>,
}

Fields

index: i32pos_x_min: Option<i32>pos_y_min: Option<i32>pos_z_min: Option<i32>pos_x_max: Option<i32>pos_y_max: Option<i32>pos_z_max: Option<i32>building_type: Option<BuildingType>material: Option<MatPair>building_flags: Option<u32>is_room: Option<bool>room: Option<BuildingExtents>direction: Option<i32>

Doesn’t mean anything for most buildings

items: Vec<BuildingItem>active: Option<i32>

Implementations

Source

impl BuildingInstance

pub fn pos_x_min(&self) -> i32

Returns the value of pos_x_min, or the default value if pos_x_min is unset.

pub fn pos_y_min(&self) -> i32

Returns the value of pos_y_min, or the default value if pos_y_min is unset.

pub fn pos_z_min(&self) -> i32

Returns the value of pos_z_min, or the default value if pos_z_min is unset.

pub fn pos_x_max(&self) -> i32

Returns the value of pos_x_max, or the default value if pos_x_max is unset.

pub fn pos_y_max(&self) -> i32

Returns the value of pos_y_max, or the default value if pos_y_max is unset.

pub fn pos_z_max(&self) -> i32

Returns the value of pos_z_max, or the default value if pos_z_max is unset.

pub fn building_flags(&self) -> u32

Returns the value of building_flags, or the default value if building_flags is unset.

pub fn is_room(&self) -> bool

Returns the value of is_room, or the default value if is_room is unset.

pub fn direction(&self) -> BuildingDirection

Returns the enum value of direction, or the default if the field is unset or set to an invalid enum value.

pub fn set_direction(&mut self, value: BuildingDirection)

Sets direction to the provided enum value.

pub fn active(&self) -> i32

Returns the value of active, or the default value if active is unset.