pub struct CasteRaw {Show 16 fields
pub index: Option<i32>,
pub caste_id: Option<String>,
pub caste_name: Vec<String>,
pub baby_name: Vec<String>,
pub child_name: Vec<String>,
pub gender: Option<i32>,
pub body_parts: Vec<BodyPartRaw>,
pub total_relsize: Option<i32>,
pub modifiers: Vec<BpAppearanceModifier>,
pub modifier_idx: Vec<i32>,
pub part_idx: Vec<i32>,
pub layer_idx: Vec<i32>,
pub body_appearance_modifiers: Vec<BpAppearanceModifier>,
pub color_modifiers: Vec<ColorModifierRaw>,
pub description: Option<String>,
pub adult_size: Option<i32>,
}Fields
index: Option<i32>caste_id: Option<String>caste_name: Vec<String>baby_name: Vec<String>child_name: Vec<String>gender: Option<i32>body_parts: Vec<BodyPartRaw>total_relsize: Option<i32>modifiers: Vec<BpAppearanceModifier>modifier_idx: Vec<i32>part_idx: Vec<i32>layer_idx: Vec<i32>body_appearance_modifiers: Vec<BpAppearanceModifier>color_modifiers: Vec<ColorModifierRaw>description: Option<String>adult_size: Option<i32>Implementations
Sourceimpl CasteRaw
impl CasteRaw
Sourcepub fn caste_id(&self) -> &str
pub fn caste_id(&self) -> &str
Returns the value of caste_id, or the default value if caste_id is unset.
Sourcepub fn gender(&self) -> i32
pub fn gender(&self) -> i32
Returns the value of gender, or the default value if gender is unset.
Sourcepub fn total_relsize(&self) -> i32
pub fn total_relsize(&self) -> i32
Returns the value of total_relsize, or the default value if total_relsize is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn adult_size(&self) -> i32
pub fn adult_size(&self) -> i32
Returns the value of adult_size, or the default value if adult_size is unset.