Cloud

Struct Cloud 

pub struct Cloud {
    pub front: Option<i32>,
    pub cumulus: Option<i32>,
    pub cirrus: Option<bool>,
    pub stratus: Option<i32>,
    pub fog: Option<i32>,
}

Fields

front: Option<i32>cumulus: Option<i32>cirrus: Option<bool>stratus: Option<i32>fog: Option<i32>

Implementations

Source

impl Cloud

pub fn front(&self) -> FrontType

Returns the enum value of front, or the default if the field is unset or set to an invalid enum value.

pub fn set_front(&mut self, value: FrontType)

Sets front to the provided enum value.

pub fn cumulus(&self) -> CumulusType

Returns the enum value of cumulus, or the default if the field is unset or set to an invalid enum value.

pub fn set_cumulus(&mut self, value: CumulusType)

Sets cumulus to the provided enum value.

pub fn cirrus(&self) -> bool

Returns the value of cirrus, or the default value if cirrus is unset.

pub fn stratus(&self) -> StratusType

Returns the enum value of stratus, or the default if the field is unset or set to an invalid enum value.

pub fn set_stratus(&mut self, value: StratusType)

Sets stratus to the provided enum value.

pub fn fog(&self) -> FogType

Returns the enum value of fog, or the default if the field is unset or set to an invalid enum value.

pub fn set_fog(&mut self, value: FogType)

Sets fog to the provided enum value.