pub struct DigCommand {
pub designation: Option<i32>,
pub locations: Vec<Coord>,
}Fields
designation: Option<i32>locations: Vec<Coord>Implementations
Sourceimpl DigCommand
impl DigCommand
Sourcepub fn designation(&self) -> TileDigDesignation
pub fn designation(&self) -> TileDigDesignation
Returns the enum value of designation, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_designation(&mut self, value: TileDigDesignation)
pub fn set_designation(&mut self, value: TileDigDesignation)
Sets designation to the provided enum value.