Engraving

Struct Engraving 

pub struct Engraving {
Show 14 fields pub pos: Option<Coord>, pub quality: Option<i32>, pub tile: Option<i32>, pub image: Option<ArtImage>, pub floor: Option<bool>, pub west: Option<bool>, pub east: Option<bool>, pub north: Option<bool>, pub south: Option<bool>, pub hidden: Option<bool>, pub northwest: Option<bool>, pub northeast: Option<bool>, pub southwest: Option<bool>, pub southeast: Option<bool>,
}

Fields

pos: Option<Coord>quality: Option<i32>tile: Option<i32>image: Option<ArtImage>floor: Option<bool>west: Option<bool>east: Option<bool>north: Option<bool>south: Option<bool>hidden: Option<bool>northwest: Option<bool>northeast: Option<bool>southwest: Option<bool>southeast: Option<bool>

Implementations

Source

impl Engraving

pub fn quality(&self) -> i32

Returns the value of quality, or the default value if quality is unset.

pub fn tile(&self) -> i32

Returns the value of tile, or the default value if tile is unset.

pub fn floor(&self) -> bool

Returns the value of floor, or the default value if floor is unset.

pub fn west(&self) -> bool

Returns the value of west, or the default value if west is unset.

pub fn east(&self) -> bool

Returns the value of east, or the default value if east is unset.

pub fn north(&self) -> bool

Returns the value of north, or the default value if north is unset.

pub fn south(&self) -> bool

Returns the value of south, or the default value if south is unset.

pub fn hidden(&self) -> bool

Returns the value of hidden, or the default value if hidden is unset.

pub fn northwest(&self) -> bool

Returns the value of northwest, or the default value if northwest is unset.

pub fn northeast(&self) -> bool

Returns the value of northeast, or the default value if northeast is unset.

pub fn southwest(&self) -> bool

Returns the value of southwest, or the default value if southwest is unset.

pub fn southeast(&self) -> bool

Returns the value of southeast, or the default value if southeast is unset.