FlowInfo

Struct FlowInfo 

pub struct FlowInfo {
Show 13 fields pub index: Option<i32>, pub type: Option<i32>, pub density: Option<i32>, pub pos: Option<Coord>, pub dest: Option<Coord>, pub expanding: Option<bool>, pub reuse: Option<bool>, pub guide_id: Option<i32>, pub material: Option<MatPair>, pub item: Option<MatPair>, pub dead: Option<bool>, pub fast: Option<bool>, pub creeping: Option<bool>,
}

Fields

index: Option<i32>type: Option<i32>density: Option<i32>pos: Option<Coord>dest: Option<Coord>expanding: Option<bool>reuse: Option<bool>
👎Deprecated
guide_id: Option<i32>material: Option<MatPair>item: Option<MatPair>dead: Option<bool>fast: Option<bool>creeping: Option<bool>

Implementations

Source

impl FlowInfo

pub fn index(&self) -> i32

Returns the value of index, or the default value if index is unset.

pub fn type(&self) -> FlowType

Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.

pub fn set_type(&mut self, value: FlowType)

Sets type to the provided enum value.

pub fn density(&self) -> i32

Returns the value of density, or the default value if density is unset.

pub fn expanding(&self) -> bool

Returns the value of expanding, or the default value if expanding is unset.

pub fn reuse(&self) -> bool

Returns the value of reuse, or the default value if reuse is unset.

pub fn guide_id(&self) -> i32

Returns the value of guide_id, or the default value if guide_id is unset.

pub fn dead(&self) -> bool

Returns the value of dead, or the default value if dead is unset.

pub fn fast(&self) -> bool

Returns the value of fast, or the default value if fast is unset.

pub fn creeping(&self) -> bool

Returns the value of creeping, or the default value if creeping is unset.