pub struct InventoryItem {
pub mode: Option<i32>,
pub item: Option<Item>,
pub body_part_id: Option<i32>,
}Fields
mode: Option<i32>item: Option<Item>body_part_id: Option<i32>Implementations
Sourceimpl InventoryItem
impl InventoryItem
Sourcepub fn mode(&self) -> InventoryMode
pub fn mode(&self) -> InventoryMode
Returns the enum value of mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: InventoryMode)
pub fn set_mode(&mut self, value: InventoryMode)
Sets mode to the provided enum value.
Sourcepub fn body_part_id(&self) -> i32
pub fn body_part_id(&self) -> i32
Returns the value of body_part_id, or the default value if body_part_id is unset.