Item

Struct Item 

pub struct Item {
Show 18 fields pub id: Option<i32>, pub pos: Option<Coord>, pub flags1: Option<u32>, pub flags2: Option<u32>, pub type: Option<MatPair>, pub material: Option<MatPair>, pub dye: Option<ColorDefinition>, pub stack_size: Option<i32>, pub subpos_x: Option<f32>, pub subpos_y: Option<f32>, pub subpos_z: Option<f32>, pub projectile: Option<bool>, pub velocity_x: Option<f32>, pub velocity_y: Option<f32>, pub velocity_z: Option<f32>, pub volume: Option<i32>, pub improvements: Vec<ItemImprovement>, pub image: Option<ArtImage>,
}

Fields

id: Option<i32>pos: Option<Coord>flags1: Option<u32>flags2: Option<u32>type: Option<MatPair>material: Option<MatPair>dye: Option<ColorDefinition>stack_size: Option<i32>subpos_x: Option<f32>subpos_y: Option<f32>subpos_z: Option<f32>projectile: Option<bool>velocity_x: Option<f32>velocity_y: Option<f32>velocity_z: Option<f32>volume: Option<i32>improvements: Vec<ItemImprovement>image: Option<ArtImage>

Implementations

Source

impl Item

pub fn id(&self) -> i32

Returns the value of id, or the default value if id is unset.

pub fn flags1(&self) -> u32

Returns the value of flags1, or the default value if flags1 is unset.

pub fn flags2(&self) -> u32

Returns the value of flags2, or the default value if flags2 is unset.

pub fn stack_size(&self) -> i32

Returns the value of stack_size, or the default value if stack_size is unset.

pub fn subpos_x(&self) -> f32

Returns the value of subpos_x, or the default value if subpos_x is unset.

pub fn subpos_y(&self) -> f32

Returns the value of subpos_y, or the default value if subpos_y is unset.

pub fn subpos_z(&self) -> f32

Returns the value of subpos_z, or the default value if subpos_z is unset.

pub fn projectile(&self) -> bool

Returns the value of projectile, or the default value if projectile is unset.

pub fn velocity_x(&self) -> f32

Returns the value of velocity_x, or the default value if velocity_x is unset.

pub fn velocity_y(&self) -> f32

Returns the value of velocity_y, or the default value if velocity_y is unset.

pub fn velocity_z(&self) -> f32

Returns the value of velocity_z, or the default value if velocity_z is unset.

pub fn volume(&self) -> i32

Returns the value of volume, or the default value if volume is unset.