pub struct MaterialDefinition {
pub mat_pair: MatPair,
pub id: Option<String>,
pub name: Option<Vec<u8>>,
pub state_color: Option<ColorDefinition>,
pub instrument: Option<InstrumentDef>,
pub up_step: Option<i32>,
pub down_step: Option<i32>,
pub layer: Option<i32>,
}Fields
mat_pair: MatPairid: Option<String>name: Option<Vec<u8>>state_color: Option<ColorDefinition>Simplifying colors to assume room temperature.
instrument: Option<InstrumentDef>up_step: Option<i32>down_step: Option<i32>layer: Option<i32>Implementations
Sourceimpl MaterialDefinition
impl MaterialDefinition
Sourcepub fn name(&self) -> &[u8] ⓘ
pub fn name(&self) -> &[u8] ⓘ
Returns the value of name, or the default value if name is unset.
Sourcepub fn up_step(&self) -> i32
pub fn up_step(&self) -> i32
Returns the value of up_step, or the default value if up_step is unset.
Sourcepub fn down_step(&self) -> i32
pub fn down_step(&self) -> i32
Returns the value of down_step, or the default value if down_step is unset.
Sourcepub fn layer(&self) -> ArmorLayer
pub fn layer(&self) -> ArmorLayer
Returns the enum value of layer, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_layer(&mut self, value: ArmorLayer)
pub fn set_layer(&mut self, value: ArmorLayer)
Sets layer to the provided enum value.