PatternDescriptor

Struct PatternDescriptor 

pub struct PatternDescriptor {
    pub id: Option<String>,
    pub colors: Vec<ColorDefinition>,
    pub pattern: Option<i32>,
}

Fields

id: Option<String>colors: Vec<ColorDefinition>pattern: Option<i32>

Implementations

Source

impl PatternDescriptor

pub fn id(&self) -> &str

Returns the value of id, or the default value if id is unset.

pub fn pattern(&self) -> PatternType

Returns the enum value of pattern, or the default if the field is unset or set to an invalid enum value.

pub fn set_pattern(&mut self, value: PatternType)

Sets pattern to the provided enum value.