PlantTile

Struct PlantTile 

pub struct PlantTile {
    pub trunk: Option<bool>,
    pub connection_east: Option<bool>,
    pub connection_south: Option<bool>,
    pub connection_west: Option<bool>,
    pub connection_north: Option<bool>,
    pub branches: Option<bool>,
    pub twigs: Option<bool>,
    pub tile_type: Option<i32>,
}

Fields

trunk: Option<bool>connection_east: Option<bool>connection_south: Option<bool>connection_west: Option<bool>connection_north: Option<bool>branches: Option<bool>twigs: Option<bool>tile_type: Option<i32>

Implementations

Source

impl PlantTile

pub fn trunk(&self) -> bool

Returns the value of trunk, or the default value if trunk is unset.

pub fn connection_east(&self) -> bool

Returns the value of connection_east, or the default value if connection_east is unset.

pub fn connection_south(&self) -> bool

Returns the value of connection_south, or the default value if connection_south is unset.

pub fn connection_west(&self) -> bool

Returns the value of connection_west, or the default value if connection_west is unset.

pub fn connection_north(&self) -> bool

Returns the value of connection_north, or the default value if connection_north is unset.

pub fn branches(&self) -> bool

Returns the value of branches, or the default value if branches is unset.

pub fn twigs(&self) -> bool

Returns the value of twigs, or the default value if twigs is unset.

pub fn tile_type(&self) -> TiletypeSpecial

Returns the enum value of tile_type, or the default if the field is unset or set to an invalid enum value.

pub fn set_tile_type(&mut self, value: TiletypeSpecial)

Sets tile_type to the provided enum value.