pub struct ScreenTile {
pub character: Option<u32>,
pub foreground: Option<u32>,
pub background: Option<u32>,
}Fields
character: Option<u32>foreground: Option<u32>background: Option<u32>Implementations
Sourceimpl ScreenTile
impl ScreenTile
Sourcepub fn character(&self) -> u32
pub fn character(&self) -> u32
Returns the value of character, or the default value if character is unset.
Sourcepub fn foreground(&self) -> u32
pub fn foreground(&self) -> u32
Returns the value of foreground, or the default value if foreground is unset.
Sourcepub fn background(&self) -> u32
pub fn background(&self) -> u32
Returns the value of background, or the default value if background is unset.