TreeGrowth

Struct TreeGrowth 

pub struct TreeGrowth {
Show 16 fields pub index: Option<i32>, pub id: Option<String>, pub name: Option<String>, pub mat: Option<MatPair>, pub prints: Vec<GrowthPrint>, pub timing_start: Option<i32>, pub timing_end: Option<i32>, pub twigs: Option<bool>, pub light_branches: Option<bool>, pub heavy_branches: Option<bool>, pub trunk: Option<bool>, pub roots: Option<bool>, pub cap: Option<bool>, pub sapling: Option<bool>, pub trunk_height_start: Option<i32>, pub trunk_height_end: Option<i32>,
}

Fields

index: Option<i32>id: Option<String>name: Option<String>mat: Option<MatPair>prints: Vec<GrowthPrint>timing_start: Option<i32>timing_end: Option<i32>twigs: Option<bool>light_branches: Option<bool>heavy_branches: Option<bool>trunk: Option<bool>roots: Option<bool>cap: Option<bool>sapling: Option<bool>trunk_height_start: Option<i32>trunk_height_end: Option<i32>

Implementations

Source

impl TreeGrowth

pub fn index(&self) -> i32

Returns the value of index, or the default value if index is unset.

pub fn id(&self) -> &str

Returns the value of id, or the default value if id is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn timing_start(&self) -> i32

Returns the value of timing_start, or the default value if timing_start is unset.

pub fn timing_end(&self) -> i32

Returns the value of timing_end, or the default value if timing_end is unset.

pub fn twigs(&self) -> bool

Returns the value of twigs, or the default value if twigs is unset.

pub fn light_branches(&self) -> bool

Returns the value of light_branches, or the default value if light_branches is unset.

pub fn heavy_branches(&self) -> bool

Returns the value of heavy_branches, or the default value if heavy_branches is unset.

pub fn trunk(&self) -> bool

Returns the value of trunk, or the default value if trunk is unset.

pub fn roots(&self) -> bool

Returns the value of roots, or the default value if roots is unset.

pub fn cap(&self) -> bool

Returns the value of cap, or the default value if cap is unset.

pub fn sapling(&self) -> bool

Returns the value of sapling, or the default value if sapling is unset.

pub fn trunk_height_start(&self) -> i32

Returns the value of trunk_height_start, or the default value if trunk_height_start is unset.

pub fn trunk_height_end(&self) -> i32

Returns the value of trunk_height_end, or the default value if trunk_height_end is unset.