UnitDefinition

Struct UnitDefinition 

pub struct UnitDefinition {
Show 26 fields pub id: i32, pub is_valid: Option<bool>, pub pos_x: Option<i32>, pub pos_y: Option<i32>, pub pos_z: Option<i32>, pub race: Option<MatPair>, pub profession_color: Option<ColorDefinition>, pub flags1: Option<u32>, pub flags2: Option<u32>, pub flags3: Option<u32>, pub is_soldier: Option<bool>, pub size_info: Option<BodySizeInfo>, pub name: Option<String>, pub blood_max: Option<i32>, pub blood_count: Option<i32>, pub appearance: Option<UnitAppearance>, pub profession_id: Option<i32>, pub noble_positions: Vec<String>, pub rider_id: Option<i32>, pub inventory: Vec<InventoryItem>, pub subpos_x: Option<f32>, pub subpos_y: Option<f32>, pub subpos_z: Option<f32>, pub facing: Option<Coord>, pub age: Option<i32>, pub wounds: Vec<UnitWound>,
}

Fields

id: i32is_valid: Option<bool>pos_x: Option<i32>pos_y: Option<i32>pos_z: Option<i32>race: Option<MatPair>profession_color: Option<ColorDefinition>flags1: Option<u32>flags2: Option<u32>flags3: Option<u32>is_soldier: Option<bool>size_info: Option<BodySizeInfo>name: Option<String>blood_max: Option<i32>blood_count: Option<i32>appearance: Option<UnitAppearance>profession_id: Option<i32>noble_positions: Vec<String>rider_id: Option<i32>inventory: Vec<InventoryItem>subpos_x: Option<f32>subpos_y: Option<f32>subpos_z: Option<f32>facing: Option<Coord>age: Option<i32>wounds: Vec<UnitWound>

Implementations

Source

impl UnitDefinition

pub fn is_valid(&self) -> bool

Returns the value of is_valid, or the default value if is_valid is unset.

pub fn pos_x(&self) -> i32

Returns the value of pos_x, or the default value if pos_x is unset.

pub fn pos_y(&self) -> i32

Returns the value of pos_y, or the default value if pos_y is unset.

pub fn pos_z(&self) -> i32

Returns the value of pos_z, or the default value if pos_z is unset.

pub fn flags1(&self) -> u32

Returns the value of flags1, or the default value if flags1 is unset.

pub fn flags2(&self) -> u32

Returns the value of flags2, or the default value if flags2 is unset.

pub fn flags3(&self) -> u32

Returns the value of flags3, or the default value if flags3 is unset.

pub fn is_soldier(&self) -> bool

Returns the value of is_soldier, or the default value if is_soldier is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn blood_max(&self) -> i32

Returns the value of blood_max, or the default value if blood_max is unset.

pub fn blood_count(&self) -> i32

Returns the value of blood_count, or the default value if blood_count is unset.

pub fn profession_id(&self) -> i32

Returns the value of profession_id, or the default value if profession_id is unset.

pub fn rider_id(&self) -> i32

Returns the value of rider_id, or the default value if rider_id is unset.

pub fn subpos_x(&self) -> f32

Returns the value of subpos_x, or the default value if subpos_x is unset.

pub fn subpos_y(&self) -> f32

Returns the value of subpos_y, or the default value if subpos_y is unset.

pub fn subpos_z(&self) -> f32

Returns the value of subpos_z, or the default value if subpos_z is unset.

pub fn age(&self) -> i32

Returns the value of age, or the default value if age is unset.