pub struct RemoteProcedureDescriptor {
pub name: &'static str,
pub plugin_name: &'static str,
pub input_type: String,
pub output_type: String,
}Expand description
Descriptor of a remote procedure call
These are all the needed information to make a call
Fields
name: &'static strName of the RPC
plugin_name: &'static strPlugin implementing the RPC
An empty string means the core API
input_type: StringInput type
This is the full name of the protobuf message
output_type: StringOutput type
This is the full name of the protobuf message