pub struct BasicUnitInfo {Show 24 fields
pub unit_id: i32,
pub pos_x: i32,
pub pos_y: i32,
pub pos_z: i32,
pub name: Option<NameInfo>,
pub flags1: u32,
pub flags2: u32,
pub flags3: u32,
pub race: i32,
pub caste: i32,
pub gender: Option<i32>,
pub civ_id: Option<i32>,
pub histfig_id: Option<i32>,
pub death_id: Option<i32>,
pub death_flags: Option<u32>,
pub squad_id: Option<i32>,
pub squad_position: Option<i32>,
pub profession: Option<i32>,
pub custom_profession: Option<String>,
pub labors: Vec<i32>,
pub skills: Vec<SkillInfo>,
pub misc_traits: Vec<UnitMiscTrait>,
pub curse: Option<UnitCurseInfo>,
pub burrows: Vec<i32>,
}Fields
unit_id: i32pos_x: i32pos_y: i32pos_z: i32name: Option<NameInfo>flags1: u32flags2: u32flags3: u32race: i32caste: i32gender: Option<i32>civ_id: Option<i32>histfig_id: Option<i32>death_id: Option<i32>death_flags: Option<u32>squad_id: Option<i32>IF mask.profession:
squad_position: Option<i32>profession: Option<i32>custom_profession: Option<String>labors: Vec<i32>IF mask.labors:
skills: Vec<SkillInfo>IF mask.skills:
misc_traits: Vec<UnitMiscTrait>IF mask.misc_traits:
curse: Option<UnitCurseInfo>burrows: Vec<i32>Implementations
Sourceimpl BasicUnitInfo
impl BasicUnitInfo
Sourcepub fn gender(&self) -> i32
pub fn gender(&self) -> i32
Returns the value of gender, or the default value if gender is unset.
Sourcepub fn civ_id(&self) -> i32
pub fn civ_id(&self) -> i32
Returns the value of civ_id, or the default value if civ_id is unset.
Sourcepub fn histfig_id(&self) -> i32
pub fn histfig_id(&self) -> i32
Returns the value of histfig_id, or the default value if histfig_id is unset.
Sourcepub fn death_id(&self) -> i32
pub fn death_id(&self) -> i32
Returns the value of death_id, or the default value if death_id is unset.
Sourcepub fn death_flags(&self) -> u32
pub fn death_flags(&self) -> u32
Returns the value of death_flags, or the default value if death_flags is unset.
Sourcepub fn squad_id(&self) -> i32
pub fn squad_id(&self) -> i32
Returns the value of squad_id, or the default value if squad_id is unset.
Sourcepub fn squad_position(&self) -> i32
pub fn squad_position(&self) -> i32
Returns the value of squad_position, or the default value if squad_position is unset.
Sourcepub fn profession(&self) -> i32
pub fn profession(&self) -> i32
Returns the value of profession, or the default value if profession is unset.
Sourcepub fn custom_profession(&self) -> &str
pub fn custom_profession(&self) -> &str
Returns the value of custom_profession, or the default value if custom_profession is unset.