pub struct BasicUnitInfoMask {
pub labors: Option<bool>,
pub skills: Option<bool>,
pub profession: Option<bool>,
pub misc_traits: Option<bool>,
}Fields
labors: Option<bool>skills: Option<bool>profession: Option<bool>misc_traits: Option<bool>Implementations
Sourceimpl BasicUnitInfoMask
impl BasicUnitInfoMask
Sourcepub fn labors(&self) -> bool
pub fn labors(&self) -> bool
Returns the value of labors, or the default value if labors is unset.
Sourcepub fn skills(&self) -> bool
pub fn skills(&self) -> bool
Returns the value of skills, or the default value if skills is unset.
Sourcepub fn profession(&self) -> bool
pub fn profession(&self) -> bool
Returns the value of profession, or the default value if profession is unset.
Sourcepub fn misc_traits(&self) -> bool
pub fn misc_traits(&self) -> bool
Returns the value of misc_traits, or the default value if misc_traits is unset.