pub struct BuildSelector {Show 13 fields
pub building_type: Option<BuildingType>,
pub stage: Option<i32>,
pub choices: Vec<BuiildReqChoice>,
pub sel_index: Option<i32>,
pub requirements: Vec<BuildItemReq>,
pub req_index: Option<i32>,
pub errors: Vec<String>,
pub radius_x_low: Option<i32>,
pub radius_y_low: Option<i32>,
pub radius_x_high: Option<i32>,
pub radius_y_high: Option<i32>,
pub cursor: Option<Coord>,
pub tiles: Vec<i32>,
}Fields
building_type: Option<BuildingType>stage: Option<i32>choices: Vec<BuiildReqChoice>sel_index: Option<i32>requirements: Vec<BuildItemReq>req_index: Option<i32>errors: Vec<String>radius_x_low: Option<i32>radius_y_low: Option<i32>radius_x_high: Option<i32>radius_y_high: Option<i32>cursor: Option<Coord>tiles: Vec<i32>Implementations
Sourceimpl BuildSelector
impl BuildSelector
Sourcepub fn stage(&self) -> BuildSelectorStage
pub fn stage(&self) -> BuildSelectorStage
Returns the enum value of stage, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stage(&mut self, value: BuildSelectorStage)
pub fn set_stage(&mut self, value: BuildSelectorStage)
Sets stage to the provided enum value.
Sourcepub fn sel_index(&self) -> i32
pub fn sel_index(&self) -> i32
Returns the value of sel_index, or the default value if sel_index is unset.
Sourcepub fn req_index(&self) -> i32
pub fn req_index(&self) -> i32
Returns the value of req_index, or the default value if req_index is unset.
Sourcepub fn radius_x_low(&self) -> i32
pub fn radius_x_low(&self) -> i32
Returns the value of radius_x_low, or the default value if radius_x_low is unset.
Sourcepub fn radius_y_low(&self) -> i32
pub fn radius_y_low(&self) -> i32
Returns the value of radius_y_low, or the default value if radius_y_low is unset.
Sourcepub fn radius_x_high(&self) -> i32
pub fn radius_x_high(&self) -> i32
Returns the value of radius_x_high, or the default value if radius_x_high is unset.
Sourcepub fn radius_y_high(&self) -> i32
pub fn radius_y_high(&self) -> i32
Returns the value of radius_y_high, or the default value if radius_y_high is unset.