pub struct InstrumentDef {Show 19 fields
pub flags: Option<InstrumentFlags>,
pub size: Option<i32>,
pub value: Option<i32>,
pub material_size: Option<i32>,
pub pieces: Vec<InstrumentPiece>,
pub pitch_range_min: Option<i32>,
pub pitch_range_max: Option<i32>,
pub volume_mb_min: Option<i32>,
pub volume_mb_max: Option<i32>,
pub sound_production: Vec<i32>,
pub sound_production_parm1: Vec<String>,
pub sound_production_parm2: Vec<String>,
pub pitch_choice: Vec<i32>,
pub pitch_choice_parm1: Vec<String>,
pub pitch_choice_parm2: Vec<String>,
pub tuning: Vec<i32>,
pub tuning_parm: Vec<String>,
pub registers: Vec<InstrumentRegister>,
pub description: Option<String>,
}Fields
flags: Option<InstrumentFlags>size: Option<i32>value: Option<i32>material_size: Option<i32>pieces: Vec<InstrumentPiece>pitch_range_min: Option<i32>pitch_range_max: Option<i32>volume_mb_min: Option<i32>volume_mb_max: Option<i32>sound_production: Vec<i32>sound_production_parm1: Vec<String>sound_production_parm2: Vec<String>pitch_choice: Vec<i32>pitch_choice_parm1: Vec<String>pitch_choice_parm2: Vec<String>tuning: Vec<i32>tuning_parm: Vec<String>registers: Vec<InstrumentRegister>description: Option<String>Implementations
Sourceimpl InstrumentDef
impl InstrumentDef
Sourcepub fn material_size(&self) -> i32
pub fn material_size(&self) -> i32
Returns the value of material_size, or the default value if material_size is unset.
Sourcepub fn pitch_range_min(&self) -> i32
pub fn pitch_range_min(&self) -> i32
Returns the value of pitch_range_min, or the default value if pitch_range_min is unset.
Sourcepub fn pitch_range_max(&self) -> i32
pub fn pitch_range_max(&self) -> i32
Returns the value of pitch_range_max, or the default value if pitch_range_max is unset.
Sourcepub fn volume_mb_min(&self) -> i32
pub fn volume_mb_min(&self) -> i32
Returns the value of volume_mb_min, or the default value if volume_mb_min is unset.
Sourcepub fn volume_mb_max(&self) -> i32
pub fn volume_mb_max(&self) -> i32
Returns the value of volume_mb_max, or the default value if volume_mb_max is unset.
Sourcepub fn sound_production(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SoundProductionType>>
pub fn sound_production( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SoundProductionType>>
Returns an iterator which yields the valid enum values contained in sound_production.
Sourcepub fn push_sound_production(&mut self, value: SoundProductionType)
pub fn push_sound_production(&mut self, value: SoundProductionType)
Appends the provided enum value to sound_production.
Sourcepub fn pitch_choice(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<PitchChoiceType>>
pub fn pitch_choice( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<PitchChoiceType>>
Returns an iterator which yields the valid enum values contained in pitch_choice.
Sourcepub fn push_pitch_choice(&mut self, value: PitchChoiceType)
pub fn push_pitch_choice(&mut self, value: PitchChoiceType)
Appends the provided enum value to pitch_choice.
Sourcepub fn tuning(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TuningType>>
pub fn tuning( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TuningType>>
Returns an iterator which yields the valid enum values contained in tuning.
Sourcepub fn push_tuning(&mut self, value: TuningType)
pub fn push_tuning(&mut self, value: TuningType)
Appends the provided enum value to tuning.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.