pub struct Cloud {
pub front: Option<i32>,
pub cumulus: Option<i32>,
pub cirrus: Option<bool>,
pub stratus: Option<i32>,
pub fog: Option<i32>,
}Fields
front: Option<i32>cumulus: Option<i32>cirrus: Option<bool>stratus: Option<i32>fog: Option<i32>Implementations
Sourceimpl Cloud
impl Cloud
Sourcepub fn front(&self) -> FrontType
pub fn front(&self) -> FrontType
Returns the enum value of front, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn cumulus(&self) -> CumulusType
pub fn cumulus(&self) -> CumulusType
Returns the enum value of cumulus, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_cumulus(&mut self, value: CumulusType)
pub fn set_cumulus(&mut self, value: CumulusType)
Sets cumulus to the provided enum value.
Sourcepub fn cirrus(&self) -> bool
pub fn cirrus(&self) -> bool
Returns the value of cirrus, or the default value if cirrus is unset.
Sourcepub fn stratus(&self) -> StratusType
pub fn stratus(&self) -> StratusType
Returns the enum value of stratus, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_stratus(&mut self, value: StratusType)
pub fn set_stratus(&mut self, value: StratusType)
Sets stratus to the provided enum value.