pub struct Engraving {Show 14 fields
pub pos: Option<Coord>,
pub quality: Option<i32>,
pub tile: Option<i32>,
pub image: Option<ArtImage>,
pub floor: Option<bool>,
pub west: Option<bool>,
pub east: Option<bool>,
pub north: Option<bool>,
pub south: Option<bool>,
pub hidden: Option<bool>,
pub northwest: Option<bool>,
pub northeast: Option<bool>,
pub southwest: Option<bool>,
pub southeast: Option<bool>,
}Fields
pos: Option<Coord>quality: Option<i32>tile: Option<i32>image: Option<ArtImage>floor: Option<bool>west: Option<bool>east: Option<bool>north: Option<bool>south: Option<bool>northwest: Option<bool>northeast: Option<bool>southwest: Option<bool>southeast: Option<bool>Implementations
Sourceimpl Engraving
impl Engraving
Sourcepub fn quality(&self) -> i32
pub fn quality(&self) -> i32
Returns the value of quality, or the default value if quality is unset.
Sourcepub fn floor(&self) -> bool
pub fn floor(&self) -> bool
Returns the value of floor, or the default value if floor is unset.
Sourcepub fn north(&self) -> bool
pub fn north(&self) -> bool
Returns the value of north, or the default value if north is unset.
Sourcepub fn south(&self) -> bool
pub fn south(&self) -> bool
Returns the value of south, or the default value if south is unset.
Returns the value of hidden, or the default value if hidden is unset.
Sourcepub fn northwest(&self) -> bool
pub fn northwest(&self) -> bool
Returns the value of northwest, or the default value if northwest is unset.
Sourcepub fn northeast(&self) -> bool
pub fn northeast(&self) -> bool
Returns the value of northeast, or the default value if northeast is unset.