pub struct PatternDescriptor {
pub id: Option<String>,
pub colors: Vec<ColorDefinition>,
pub pattern: Option<i32>,
}Fields
id: Option<String>colors: Vec<ColorDefinition>pattern: Option<i32>Implementations
Sourceimpl PatternDescriptor
impl PatternDescriptor
Sourcepub fn pattern(&self) -> PatternType
pub fn pattern(&self) -> PatternType
Returns the enum value of pattern, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_pattern(&mut self, value: PatternType)
pub fn set_pattern(&mut self, value: PatternType)
Sets pattern to the provided enum value.