pub struct TreeGrowth {Show 16 fields
pub index: Option<i32>,
pub id: Option<String>,
pub name: Option<String>,
pub mat: Option<MatPair>,
pub prints: Vec<GrowthPrint>,
pub timing_start: Option<i32>,
pub timing_end: Option<i32>,
pub twigs: Option<bool>,
pub light_branches: Option<bool>,
pub heavy_branches: Option<bool>,
pub trunk: Option<bool>,
pub roots: Option<bool>,
pub cap: Option<bool>,
pub sapling: Option<bool>,
pub trunk_height_start: Option<i32>,
pub trunk_height_end: Option<i32>,
}Fields
index: Option<i32>id: Option<String>name: Option<String>mat: Option<MatPair>prints: Vec<GrowthPrint>timing_start: Option<i32>timing_end: Option<i32>twigs: Option<bool>light_branches: Option<bool>heavy_branches: Option<bool>trunk: Option<bool>roots: Option<bool>cap: Option<bool>sapling: Option<bool>trunk_height_start: Option<i32>trunk_height_end: Option<i32>Implementations
Sourceimpl TreeGrowth
impl TreeGrowth
Sourcepub fn timing_start(&self) -> i32
pub fn timing_start(&self) -> i32
Returns the value of timing_start, or the default value if timing_start is unset.
Sourcepub fn timing_end(&self) -> i32
pub fn timing_end(&self) -> i32
Returns the value of timing_end, or the default value if timing_end is unset.
Sourcepub fn twigs(&self) -> bool
pub fn twigs(&self) -> bool
Returns the value of twigs, or the default value if twigs is unset.
Sourcepub fn light_branches(&self) -> bool
pub fn light_branches(&self) -> bool
Returns the value of light_branches, or the default value if light_branches is unset.
Sourcepub fn heavy_branches(&self) -> bool
pub fn heavy_branches(&self) -> bool
Returns the value of heavy_branches, or the default value if heavy_branches is unset.
Sourcepub fn trunk(&self) -> bool
pub fn trunk(&self) -> bool
Returns the value of trunk, or the default value if trunk is unset.
Sourcepub fn roots(&self) -> bool
pub fn roots(&self) -> bool
Returns the value of roots, or the default value if roots is unset.
Sourcepub fn sapling(&self) -> bool
pub fn sapling(&self) -> bool
Returns the value of sapling, or the default value if sapling is unset.
Sourcepub fn trunk_height_start(&self) -> i32
pub fn trunk_height_start(&self) -> i32
Returns the value of trunk_height_start, or the default value if trunk_height_start is unset.
Sourcepub fn trunk_height_end(&self) -> i32
pub fn trunk_height_end(&self) -> i32
Returns the value of trunk_height_end, or the default value if trunk_height_end is unset.