pub struct WorldMap {Show 25 fields
pub world_width: i32,
pub world_height: i32,
pub name: Option<Vec<u8>>,
pub name_english: Option<String>,
pub elevation: Vec<i32>,
pub rainfall: Vec<i32>,
pub vegetation: Vec<i32>,
pub temperature: Vec<i32>,
pub evilness: Vec<i32>,
pub drainage: Vec<i32>,
pub volcanism: Vec<i32>,
pub savagery: Vec<i32>,
pub clouds: Vec<Cloud>,
pub salinity: Vec<i32>,
pub map_x: Option<i32>,
pub map_y: Option<i32>,
pub center_x: Option<i32>,
pub center_y: Option<i32>,
pub center_z: Option<i32>,
pub cur_year: Option<i32>,
pub cur_year_tick: Option<i32>,
pub world_poles: Option<i32>,
pub river_tiles: Vec<RiverTile>,
pub water_elevation: Vec<i32>,
pub region_tiles: Vec<RegionTile>,
}Fields
world_width: i32world_height: i32name: Option<Vec<u8>>name_english: Option<String>elevation: Vec<i32>rainfall: Vec<i32>vegetation: Vec<i32>temperature: Vec<i32>evilness: Vec<i32>drainage: Vec<i32>volcanism: Vec<i32>savagery: Vec<i32>clouds: Vec<Cloud>salinity: Vec<i32>map_x: Option<i32>map_y: Option<i32>center_x: Option<i32>center_y: Option<i32>center_z: Option<i32>cur_year: Option<i32>cur_year_tick: Option<i32>world_poles: Option<i32>river_tiles: Vec<RiverTile>water_elevation: Vec<i32>region_tiles: Vec<RegionTile>Implementations
Sourceimpl WorldMap
impl WorldMap
Sourcepub fn name(&self) -> &[u8] ⓘ
pub fn name(&self) -> &[u8] ⓘ
Returns the value of name, or the default value if name is unset.
Sourcepub fn name_english(&self) -> &str
pub fn name_english(&self) -> &str
Returns the value of name_english, or the default value if name_english is unset.
Sourcepub fn center_x(&self) -> i32
pub fn center_x(&self) -> i32
Returns the value of center_x, or the default value if center_x is unset.
Sourcepub fn center_y(&self) -> i32
pub fn center_y(&self) -> i32
Returns the value of center_y, or the default value if center_y is unset.
Sourcepub fn center_z(&self) -> i32
pub fn center_z(&self) -> i32
Returns the value of center_z, or the default value if center_z is unset.
Sourcepub fn cur_year(&self) -> i32
pub fn cur_year(&self) -> i32
Returns the value of cur_year, or the default value if cur_year is unset.
Sourcepub fn cur_year_tick(&self) -> i32
pub fn cur_year_tick(&self) -> i32
Returns the value of cur_year_tick, or the default value if cur_year_tick is unset.
Sourcepub fn world_poles(&self) -> WorldPoles
pub fn world_poles(&self) -> WorldPoles
Returns the enum value of world_poles, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_world_poles(&mut self, value: WorldPoles)
pub fn set_world_poles(&mut self, value: WorldPoles)
Sets world_poles to the provided enum value.